@@ -1098,7 +1098,7 @@ if(length(vec.factor) > 0){
 # 	print(dim(varformula2))
 # 	print(dim(vardc))
 
-	ans <- .Fortran("jointMultiv",
+	ans <- .Fortran(C_joint_multiv,
 		as.integer(nobsEvent),
 		as.integer(n.knots),
 		k0=as.double(kappa),
@@ -1167,8 +1167,9 @@ if(length(vec.factor) > 0){
 		
 		time=as.double(time),
 		timedc=as.double(timedc),
-		time2=as.double(time2),
-	PACKAGE = "frailtypack")#63 arguments
+		time2=as.double(time2)
+		)#,
+	# PACKAGE = "frailtypack")#63 arguments
 
 
 	if (ans$critCV[2] == 4){
@@ -1244,7 +1245,15 @@ if(length(vec.factor) > 0){
     fit$varH <- temp1[(np - (nvar) - 1):np, (np - (nvar) - 1):np]
     fit$varHIH <- temp2[(np - (nvar) - 1):np, (np - (nvar) - 1):np]
 
-
+    seH.theta1 <- sqrt(((2 * (fit$theta1^0.5))^2) * diag(fit$varH)[1])
+    fit$theta1_p.value <- 1 - pnorm(fit$theta1/seH.theta1)
+    
+    seH.theta2 <- sqrt(((2 * (fit$theta2^0.5))^2) * diag(fit$varH)[2])
+    fit$theta2_p.value <- 1 - pnorm(fit$theta2/seH.theta2)
+    
+    fit$alpha1_p.value <- 1 - pchisq((fit$alpha1/sqrt(diag(fit$varH))[3])^2,1)
+    fit$alpha2_p.value <- 1 - pchisq((fit$alpha2/sqrt(diag(fit$varH))[4])^2,1)
+    
 
     fit$formula <- formula(Terms.formula)
     fit$formula.terminalEvent <- formula(Terms2)
@@ -1408,7 +1417,8 @@ if(length(vec.factor) > 0){
 	}else{
 		fit$global_chisq.test2 <- 0
 	}
-
+	fit$beta_p.value <- 1 - pchisq((fit$coef/sqrt(diag(fit$varH))[-c(1,2)])^2,1 )
+	
 
 	class(fit) <- "multivPenal"
 
